@@ -1,13 +1,15 @@
+"""Class to manipulate a process"""
 import os
 from lutris.util.log import logger
-from lutris.util.system import kill_pid, path_exists
+from lutris.util.system import path_exists
 
 
 class InvalidPid(Exception):
-    pass
+    """Exception raised when an operation on a non-existent PID is called"""
 
 
 class Process:
+    """Python abstraction a Linux process"""
     def __init__(self, pid, parent=None):
         try:
             self.pid = int(pid)
@@ -31,7 +33,7 @@ class Process:
             try:
                 _stat = stat_file.readline()
             except (ProcessLookupError, FileNotFoundError):
-                logger.warning('Unable to read stat for process %s', self.pid)
+                logger.warning("Unable to read stat for process %s", self.pid)
                 return None
         if parsed:
             return _stat[_stat.rfind(")") + 1:].split()
@@ -39,7 +41,7 @@ class Process:
 
     def get_thread_ids(self):
         """Return a list of thread ids opened by process."""
-        basedir = '/proc/{}/task/'.format(self.pid)
+        basedir = "/proc/{}/task/".format(self.pid)
         if os.path.isdir(basedir):
             try:
                 return [tid for tid in os.listdir(basedir)]
@@ -50,12 +52,12 @@ class Process:
 
     def get_children_pids_of_thread(self, tid):
         """Return pids of child processes opened by thread `tid` of process."""
-        children_path = '/proc/{}/task/{}/children'.format(self.pid, tid)
+        children_path = "/proc/{}/task/{}/children".format(self.pid, tid)
         try:
             with open(children_path) as children_file:
                 children_content = children_file.read()
         except FileNotFoundError:
-            children_content = ''
+            children_content = ""
         return children_content.strip().split()
 
     def get_children(self):
@@ -84,41 +86,16 @@ class Process:
             return _stat[0]
         return None
 
-    @property
-    def ppid(self):
-        """PID of the parent."""
-        _stat = self.get_stat()
-        if _stat:
-            return _stat[1]
-        return None
-
-    @property
-    def pgrp(self):
-        """Process group ID of the process."""
-        _stat = self.get_stat()
-        if _stat:
-            return _stat[2]
-        return None
-
     @property
     def cmdline(self):
         """Return command line used to run the process `pid`."""
-        cmdline_path = '/proc/{}/cmdline'.format(self.pid)
+        cmdline_path = "/proc/{}/cmdline".format(self.pid)
         with open(cmdline_path) as cmdline_file:
-            _cmdline = cmdline_file.read().replace('\x00', ' ')
+            _cmdline = cmdline_file.read().replace("\x00", " ")
         return _cmdline
 
     @property
     def cwd(self):
-        cwd_path = '/proc/%d/cwd' % int(self.pid)
+        """Return current working dir of process"""
+        cwd_path = "/proc/%d/cwd" % int(self.pid)
         return os.readlink(cwd_path)
-
-    def kill(self, killed_processes=None):
-        if not killed_processes:
-            killed_processes = set()
-        for child_pid in reversed(sorted(self.get_thread_ids())):
-            child = Process(child_pid)
-            if child.pid not in killed_processes:
-                killed_processes.add(child.pid)
-                child.kill(killed_processes)
-        kill_pid(self.pid)
